@@ -2,7 +2,8 @@ import sys
 import json
 import getpass
 import docker.errors
-from cowait.tasks import TaskDefinition
+from datetime import datetime
+from cowait.tasks.definition import TaskDefinition, generate_task_id
 from cowait.engine.errors import TaskCreationError, ProviderError
 from cowait.tasks.messages import TASK_INIT, TASK_STATUS, TASK_FAIL, TASK_RETURN, TASK_LOG
 from ..config import Config
@@ -39,6 +40,7 @@ def run(
     quiet: bool = False,
     affinity: str = None,
     cluster_name: str = None,
+    deploy: bool = False,
 ):
     logger = RunLogger(raw, quiet)
     try:
@@ -72,7 +74,7 @@ def run(
 
         # create task definition
         taskdef = TaskDefinition(
-            id=name,
+            id=generate_task_id(task, unique=not deploy),
             name=task,
             image=image,
             inputs=inputs,
@@ -101,16 +103,20 @@ def run(
             TaskImage.pull(image, tag='latest')
 
         # submit task to cluster
-        task = cluster.spawn(taskdef)
+        task = cluster.spawn(taskdef, deploy=deploy)
 
         if detach:
             logger.header('detached')
             return
 
         def destroy(*args):
-            logger.header('interrupt')
-            cluster.destroy(task.id)
-            sys.exit(1)
+            if deploy:
+                logger.header('detached')
+                sys.exit(0)
+            else:
+                logger.header('interrupt')
+                cluster.destroy(task.id)
+                sys.exit(1)
 
         with ExitTrap(destroy):
             # capture & print logs
@@ -118,6 +124,7 @@ def run(
             logger.header('task output')
             for msg in logs:
                 logger.handle(msg)
+            logger.finalize()
 
         logger.header()
 
@@ -142,6 +149,8 @@ class RunLogger(Logger):
         super().__init__(quiet, time)
         self.raw = raw
         self.idlen = 0
+        self.returned = False
+        self.failed = False
 
     @property
     def newline_indent(self):
@@ -163,8 +172,14 @@ class RunLogger(Logger):
             if type == TASK_INIT:
                 self.on_init(**msg)
             elif type == TASK_RETURN:
+                if msg['id'] == self.id:
+                    # mark task as returned
+                    self.returned = True
                 self.on_return(**msg)
             elif type == TASK_FAIL:
+                if msg['id'] == self.id:
+                    # mark task as failed
+                    self.failed = True
                 self.on_fail(**msg)
             elif type == TASK_STATUS:
                 pass
@@ -199,8 +214,10 @@ class RunLogger(Logger):
             return
         super().print(*args)
 
-    def print_id(self, id, ts=None, short=True, pad=True):
+    def print_id(self, id, short=True, pad=True):
         color = fg(hash(id) % 214 + 17)
+        if id == 'system':
+            color = fg('red')
         if short and '-' in id:
             id = id[:id.rfind('-')]
             self.idlen = max(self.idlen, len(id))
@@ -241,3 +258,16 @@ class RunLogger(Logger):
         self.print_time(ts)
         self.print_id(id)
         self.println('  ', data)
+
+    def finalize(self):
+        if self.returned or self.failed:
+            return
+        ts = datetime.now().isoformat()
+        error = (f'Reached end of log stream without return or failure. '
+                 f'Task {self.id} appears to have been lost.')
+        if self.raw:
+            # print a raw error
+            if not self.quiet:
+                print(json.dumps({'id': 'system', 'type': TASK_FAIL, 'error': error, 'ts': ts}))
+        else:
+            self.on_fail(id='system', ts=ts, error=error)
